/* Copyright 2013-2019 Homegear GmbH
 *
 * Homegear is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Homegear is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Homegear.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef PHILIPSHUEPACKET_H_
#define PHILIPSHUEPACKET_H_

#include <homegear-base/BaseLib.h>

#include <map>

using namespace BaseLib;

namespace PhilipsHue
{
class PhilipsHuePacket : public BaseLib::Systems::Packet
{
public:
    enum class Category
    {
        light = 0,
        group = 1,
        sensor = 2
    };

    //Properties
    PhilipsHuePacket();
    PhilipsHuePacket(Category category, int32_t senderAddress, int32_t destinationAddress, uint8_t messageType, PVariable json, int64_t timeReceived = 0);
    virtual ~PhilipsHuePacket();

    Category getCategory() { return _category; }

    int32_t senderAddress() { return _senderAddress; }
    int32_t destinationAddress() { return _destinationAddress; }
    uint8_t getMessageType() { return _messageType; }
    void setMessageType(uint8_t type) { _messageType = type; }

    virtual PVariable getJson() { return _json; }
    virtual void setJson(PVariable value) { _json = value; }
protected:
    PVariable _json;
    Category _category = Category::light;
    int32_t _senderAddress = 0;
    int32_t _destinationAddress = 0;
    uint8_t _messageType = 0;
};

}
#endif
